@@ -13,8 +13,8 @@ from .credentials import Credentials
 from .access_token_response import AccessTokenResponse
 from .exceptions import AuthorizationError
 
-cache = TTLCache(maxsize=int(os.environ.get('SP_API_AUTH_CACHE_SIZE', 10)), ttl=3600)
-grantless_cache = TTLCache(maxsize=int(os.environ.get('SP_API_AUTH_CACHE_SIZE', 10)), ttl=3600)
+cache = TTLCache(maxsize=int(os.environ.get('SP_API_AUTH_CACHE_SIZE', 10)), ttl=3200)
+grantless_cache = TTLCache(maxsize=int(os.environ.get('SP_API_AUTH_CACHE_SIZE', 10)), ttl=3200)
 
 logger = logging.getLogger(__name__)
 
@@ -127,6 +127,6 @@ class AccessTokenClient(BaseClient):
 
     def _get_cache_key(self, token_flavor=''):
         return 'access_token_' + hashlib.md5(
-            (token_flavor + self.cred.refresh_token).encode('utf-8')
+            (token_flavor + (self.cred.refresh_token or '__grantless__')).encode('utf-8')
         ).hexdigest()
 
